@@ -4,8 +4,7 @@ from collections import namedtuple
 def named_tuple_factory(cursor):
     """
     Returns a named tuple when querying
-    Usage:
-        cursor.rowfactory = named_tuple_factory(cursor)
+    Usage: `cursor.rowfactory = named_tuple_factory(cursor)`
     """
     column_names = [d[0].lower() for d in cursor.description]
     row = namedtuple("Row", column_names)
@@ -15,8 +14,7 @@ def named_tuple_factory(cursor):
 def dict_factory(cursor):
     """
     Returns a dictionary when querying
-    Usage:
-        cursor.rowfactory = dict_factory(cursor)
+    Usage: `cursor.rowfactory = dict_factory(cursor)`
     """
     column_names = [d[0].lower() for d in cursor.description]
 
